@@ -1,5 +1,5 @@
 /* OpenVAS
-* $Id: attack.c 2463 2009-02-12 13:42:11Z felix $
+* $Id: attack.c 4581 2009-08-19 08:46:49Z felix $
 * Description: Launches the plugins, and manages multithreading.
 *
 * Authors: - Renaud Deraison <deraison@nessus.org> (Original pre-fork develoment)
@@ -240,7 +240,15 @@ launch_plugin (struct arglist * globals, plugins_scheduler_t * sched,
             }
           }
 
-      if(!optimize || !(error = requirements_plugin(kb, plugin, preferences)))
+      // Do not launch NVT if mandatory key is missing (e.g. an important tool
+      // was not found)
+      if (mandatory_requirements_met(kb, plugin))
+        error = NULL;
+      else
+        error = "because a mandatory key is missing";
+
+      if (!error
+          && (!optimize || !(error = requirements_plugin (kb, plugin, preferences))))
         {
           int pid;
 
@@ -416,6 +424,9 @@ fill_host_kb_ssh_credentials (struct kb_item** kb, struct arglist* globals,
   if (login->username)
     kb_item_set_str (kb, "Secret/SSH/login", login->username);
 
+  if (login->userpassword)
+    kb_item_set_str (kb, "Secret/SSH/password", login->userpassword);
+
   if (login->ssh_key_passphrase)
     kb_item_set_str (kb, "Secret/SSH/passphrase", login->ssh_key_passphrase);
 
