@@ -1,5 +1,5 @@
 /* OpenVAS
-* $Id: ntp_11.c 1759 2008-11-17 10:40:29Z felix $
+* $Id: ntp_11.c 2462 2009-02-12 13:41:05Z felix $
 * Description: OpenVAS Communication Manager; it manages the OpenVAS Transfer Protocol,
 * version 1.1 and 1.2.
 *
@@ -46,6 +46,8 @@
 #include "save_tests.h"
 #include "preferences.h"
 #include "hosts.h"
+#include "hash_table_file.h"
+#include "openvas_ssh_login.h"
 
 #ifndef MIN
 #define MIN(x,y) ((x) < (y) ? (x):(y))
@@ -67,9 +69,9 @@ static int ntp_11_list_sessions(struct arglist*);
 static int ntp_11_delete_session(struct arglist*, char*);
 static int ntp_11_restore_session(struct arglist*, char*);
 #endif
-/*
- * Parses the input sent by the client before
- * the NEW_ATTACK message.
+
+/**
+ * @brief Parses the input sent by the client before the NEW_ATTACK message.
  */
 int ntp_11_parse_input(globals, input)
    struct arglist * globals;
@@ -241,7 +243,8 @@ ntp_11_long_attack(globals, orig)
 } 
 
 /**
- * Reads in prefs sent by client.
+ * @brief Reads in "server" prefs sent by client.
+ * 
  * @param globals The global arglist (containing server preferences).
  * @return Always 0.
  */
@@ -388,12 +391,20 @@ ntp_11_show_end(globals, name, internal)
 	auth_printf(globals, "%s", buf);
 }
 
-
+/**
+ * @brief Adds a 'translation' entry for a file sent by the client.
+ * 
+ * Files sent by the client are stored temporarily at server side.
+ * In order to access these files, their original paths ('local' to the client)
+ * can be 'translated' into the file paths of the temporary files on server side.
+ * 
+ * @param globals    Global arglist.
+ * @param remotename Path to file as referenced by the client.
+ * @param remotename Path to file as referenced by the server.
+ */
 static void
-files_add_translation(globals, remotename, localname)
- struct arglist * globals;
- char * remotename;
- char * localname;
+files_add_translation (struct arglist* globals, char * remotename, 
+                       char * localname)
 {
  harglst * trans = arg_get_value(globals, "files_translation");
 #if 0
@@ -411,95 +422,169 @@ files_add_translation(globals, remotename, localname)
  	harg_set_string(trans, remotename, localname);
 }
 
-
-
-int
-ntp_11_recv_file(globals)
- struct arglist * globals;
+/**
+ * @brief Reads in a hashtable from file that maps login-account names to host
+ *        names.
+ * 
+ * On client side the file is known as .host_logins (if defined, found in each
+ * task directory).
+ * The GHashTable will be available through the (global) arglist under the key
+ * "MAP_HOST_SSHLOGIN_NAME".
+ * 
+ * @param globals  Arglist to add the GHashTable to.
+ * @param filepath Path to file with serialized GHashTable.
+ */
+static void
+build_global_host_sshlogins_map (struct arglist* globals, char* filepath)
 {
- int soc = GPOINTER_TO_SIZE(arg_get_value(globals, "global_socket"));
- char input[4096];
- char * origname, * localname = temp_file_name();
- int n;
- long bytes = 0;
- long tot = 0;
- int fd;
- 
+  // Deserialize the hashtable that mapped login-account names to host names.
+  GHashTable* map_host_sshlogin_name = hash_table_file_read (filepath);
+  // Add or replace it in the arglist
+  if (map_host_sshlogin_name!= NULL
+      && arg_get_value (globals, "MAP_HOST_SSHLOGIN_NAME") == NULL)
+    arg_add_value (globals, "MAP_HOST_SSHLOGIN_NAME", ARG_PTR, -1, map_host_sshlogin_name);
+  else if (map_host_sshlogin_name!= NULL)
+    arg_set_value (globals, "MAP_HOST_SSHLOGIN_NAME", -1, map_host_sshlogin_name);
+}
+
+/**
+ * @brief Reads a ssh login file with mapping that was sent by the client.
+ * 
+ * The file (local to the client called '.logins') is used to create a
+ * GHashTable that maps openvas_ssh_login structs to the user-defined names for
+ * login-accounts.
+ * 
+ * If successful, the map is available under the key "MAP_NAME_SSHLOGIN".
+ * For it 
+ * 
+ * @param globals  Global arglist to add the map to.
+ * @param filepath Path to the file '.logins' as translated.
+ */
+static void
+build_global_sshlogin_info_map (struct arglist* globals, char* filepath)
+{
+  // Read the file, build map of names->structs
+  GHashTable* ssh_logins = openvas_ssh_login_file_read (filepath, FALSE);
+  // Add/ Replace, if not-empty
+  if (ssh_logins != NULL && arg_get_value (globals, "MAP_NAME_SSHLOGIN") == NULL)
+    arg_add_value (globals, "MAP_NAME_SSHLOGIN", ARG_PTR, -1, ssh_logins);
+  else if (ssh_logins != NULL)
+    arg_set_value (globals, "MAP_NAME_SSHLOGIN", -1, ssh_logins);
+}
+
+
+/**
+ * @brief Receive a file sent by the client.
+ * 
+ * Two files receive an extra treatment: <br>
+ *  - The .logins file sent by a client is used to build a store for login 
+ * information.
+ *  - The .host_sshlogins file sent by the client is used to map keys to
+ * hostnames.
+ * 
+ * @return 0 if successful, -1 in case of errors.
+ */
+int
+ntp_11_recv_file (struct arglist* globals)
+{
+  int soc = GPOINTER_TO_SIZE(arg_get_value(globals, "global_socket"));
+  char input[4096];
+  char * origname, * localname = temp_file_name();
+  int n;
+  long bytes = 0;
+  long tot = 0;
+  int fd;
+
 #if 0
  fprintf(stderr, "ntp_11_recv_file\n");
 #endif
- n = recv_line(soc, input, sizeof(input) - 1);
- if(n <= 0)
-  return -1;
-  
- if( strncmp(input, "name: ", strlen("name: ")) == 0 )
- {
-  origname = estrdup(input + sizeof("name: ")-1);
-  if(origname[strlen(origname) - 1] == '\n')
-   origname[strlen(origname) - 1] = '\0';
- }
- else 
-   return -1;
- 
- n = recv_line(soc, input, sizeof(input) - 1);
- if(n <= 0)
-  return -1;
- /* XXX content: message. Ignored for the moment */
- 
- n = recv_line(soc, input, sizeof(input) - 1);
- if(n <= 0)
 
-  return -1;
-  
- if( strncmp(input, "bytes: ", sizeof("bytes: ")-1) == 0 )
- {
-  char * t = input + sizeof("bytes: ")-1;
-  bytes = atol(t);
- }
- else 
-  return -1;
-  
- /*
-  * Ok. We now know that we have to read <bytes> bytes from the
-  * remote socket.
-  */
-  
+  n = recv_line(soc, input, sizeof(input) - 1);
+  if (n <= 0)
+    return -1;
+
+  if ( strncmp(input, "name: ", strlen("name: ")) == 0 )
+    {
+      origname = estrdup(input + sizeof("name: ")-1);
+      if(origname[strlen(origname) - 1] == '\n')
+      origname[strlen(origname) - 1] = '\0';
+    }
+  else
+    return -1;
+
+  n = recv_line(soc, input, sizeof(input) - 1);
+  if (n <= 0)
+    return -1;
+  /* XXX content: message. Ignored for the moment */
+
+  n = recv_line (soc, input, sizeof(input) - 1);
+  if (n <= 0)
+    return -1;
+
+  if ( strncmp(input, "bytes: ", sizeof("bytes: ")-1) == 0 )
+    {
+      char * t = input + sizeof("bytes: ")-1;
+      bytes = atol(t);
+    }
+  else
+    return -1;
+
+  /* We now know that we have to read <bytes> bytes from the remote socket. */
+
   fd = open(localname, O_CREAT|O_WRONLY|O_TRUNC, 0600);
-  if(fd < 0)
-  {
-   perror("ntp_11_recv_file: open() ");
-   return -1;
-  }
+  if (fd < 0)
+    {
+      perror ("ntp_11_recv_file: open() ");
+      return -1;
+    }
+
 #if 0
   fprintf(stderr, "ntp_11_recv_file: localname=%s\n", localname);
 #endif  
-  while(tot < bytes)
-  {
-   bzero(input, sizeof(input));
-   n = nrecv(soc, input, MIN(sizeof(input)-1, bytes - tot), 0);
-   if(n  < 0)
-   {
-     char	s[80];
-     sprintf(s, "11_recv_file: nrecv(%d)", soc);
-    perror(s);
-    break;
-   }
-   else
-   {
-    write(fd, input, n);
-    tot += n;
-   }
-  }
-  /*
-   * Add the fact that what the remote client calls
-   * <filename> is actually <localname> here
-   */
-  auth_printf(globals, "SERVER <|> FILE_ACCEPTED <|> SERVER\n"); 
-  files_add_translation(globals, origname, localname);
-  efree(&localname);
-  close(fd);
+
+  while (tot < bytes)
+    {
+      bzero (input, sizeof(input));
+      n = nrecv (soc, input, MIN(sizeof(input)-1, bytes - tot), 0);
+      if (n  < 0)
+        {
+          char s[80];
+          sprintf (s, "11_recv_file: nrecv(%d)", soc);
+          perror (s);
+          break;
+        }
+      else
+        {
+          write (fd, input, n);
+          tot += n;
+        }
+    }
+  auth_printf (globals, "SERVER <|> FILE_ACCEPTED <|> SERVER\n"); 
+  /* Add the fact that what the remote client calls <filename> is actually 
+   * <localname> here. */
+  files_add_translation (globals, origname, localname);
+  
+  close (fd);
+
+  // Check for files that are handled in a special manner access per-host
+  // login information.
+  gchar* origname_file = g_path_get_basename (origname);
+  if (!strcmp (origname_file, ".host_sshlogins"))
+    {
+      build_global_host_sshlogins_map (globals, localname);
+    }
+  else if (!strcmp (origname_file, ".logins"))
+    {
+      build_global_sshlogin_info_map (globals, localname);
+    }
+
+  efree (&localname);
+  g_free (origname);
+  g_free (origname_file);
+  
   return 0;
 }
+
 #ifdef ENABLE_SAVE_TESTS
 static char*
 extract_session_key_from_session_msg(globals, orig)
