@@ -1,5 +1,5 @@
 /* OpenVAS
-* $Id: pluginscheduler.c 2470 2009-02-13 00:17:32Z jan $
+* $Id: pluginscheduler.c 4274 2009-07-30 22:02:48Z jan $
 * Description: Tells openvasd which plugin should be executed next.
 *
 * Authors: - Renaud Deraison <deraison@nessus.org> (Original pre-fork develoment)
@@ -355,10 +355,29 @@ static void hash_fill_deps(struct hash * h, struct hash * l )
 	if ( d != NULL )
 	 l->dependencies_ptr[j++] = d;
         else
-          log_write("scheduler: %s depends on %s which could not be found, thus this dependency is not considered for execution sequence\n", l->plugin->arglist->name, l->dependencies[i]);
-	}
-   l->dependencies_ptr[j] = NULL;
+          {
+            gchar *path = g_path_get_dirname (l->plugin->arglist->name);
+            if (g_ascii_strcasecmp (path, ".") != 0)
+              {
+                gchar *dep_with_path = g_build_filename (path, l->dependencies[i], NULL);
+                log_write ("scheduler: dependency %s not found, trying %s",
+                           l->dependencies[i], dep_with_path);
+                d = _hash_get (h, dep_with_path);
+                g_free (dep_with_path);
+              }
+            g_free (path);
+            if (d != NULL)
+              {
+                l->dependencies_ptr[j++] = d;
+              }
+            else
+              {
+                log_write("scheduler: %s depends on %s which could not be found, thus this dependency is not considered for execution sequence\n", l->plugin->arglist->name, l->dependencies[i]);
+              }
+          }
   }
+  l->dependencies_ptr[j] = NULL;
+ }
 }
 
 /*----------------------------------------------------------------------*/
@@ -623,6 +642,7 @@ plugins_scheduler_t plugins_scheduler_init(struct arglist * plugins, int autoloa
   scheduler_plugin->required_ports = plug_get_required_ports(arg->value);
   scheduler_plugin->required_udp_ports = plug_get_required_udp_ports(arg->value);
   scheduler_plugin->required_keys = plug_get_required_keys(arg->value);
+  scheduler_plugin->mandatory_keys = plug_get_mandatory_keys(arg->value);
   scheduler_plugin->excluded_keys = plug_get_excluded_keys(arg->value);
  
 
