@@ -1,5 +1,5 @@
 /* OpenVAS
-* $Id: preferences.c 2502 2009-02-17 08:55:42Z felix $
+* $Id: preferences.c 2529 2009-02-19 11:00:30Z felix $
 * Description: Loads the preferences set in openvasd.conf into the memory. 
 *
 * Authors: - Renaud Deraison <deraison@nessus.org> (Original pre-fork develoment)
@@ -26,7 +26,24 @@
 *
 *
 */
- 
+
+/** @file
+ * 'Server' Preference related functions (some of them scan-related).
+ * 
+ * All the preference getter- functions for pseudo boolean values work in the
+ * same fashion.
+ * The static 'yes' value is initialized only the first time the function is
+ * called. If then preferences != NULL, the arglist is queried, otherwise the
+ * value keeps being or is resetted to -1.
+ * On subsequent calls where preferences != NULL, the arglist does not have
+ * to be queried anymore.
+ * Resetting this "cache"s is possible by calling preferences_reset_cache.
+ * 
+ * FIXME: Bacause of the static nature of the cache, the start of a new scan
+ * with different 'server' preference values might override the values for a
+ * already running scan, isnt it?
+ */
+
 #include <includes.h>
 #include <hosts_gatherer.h>
 
@@ -124,7 +141,7 @@ int preferences_new(char * name)
  fprintf(fd, "\n\n# Automatically activate the plugins that are depended on\n");
  fprintf(fd, "auto_enable_dependencies = yes\n");
  fprintf(fd, "\n\n# Do not echo data from plugins which have been automatically enabled\n");
- fprintf(fd, "silent_dependencies = yes\n");
+ fprintf(fd, "silent_dependencies = no\n");
  fprintf(fd, "\n\n# Designate hosts by MAC address, not IP address (useful for DHCP networks)\n");
  fprintf(fd, "use_mac_addr = no\n");
  
@@ -323,7 +340,6 @@ preferences_get_checks_read_timeout (struct arglist *preferences)
  return ret;
 }
 
-
 int preferences_log_whole_attack(preferences)
  struct arglist * preferences;
 {
@@ -697,8 +713,7 @@ preferences_report_killed_plugins(preferences)
 }
 
 int
-preferences_silent_dependencies(preferences)
- struct arglist * preferences;
+preferences_silent_dependencies (struct arglist * preferences)
 {
  static int yes = -1;
  char * pref;
@@ -738,6 +753,13 @@ preferences_get_string(preferences, name)
 }
 
 
+/**
+ * @brief Resets the preference caches.
+ * 
+ * Subsequent calls to the pseudo-boolean preference getters like
+ * preferences_silent_dependencies will query a given arglist once and refill
+ * the caches.
+ */
 void
 preferences_reset_cache()
 {
