@@ -1,5 +1,5 @@
 /* OpenVAS
-* $Id: utils.c 2504 2009-02-17 09:10:09Z felix $
+* $Id: utils.c 4285 2009-07-31 20:52:11Z jan $
 * Description: A bunch of miscellaneous functions, mostly file conversions.
 *
 * Authors: - Renaud Deraison <deraison@nessus.org> (Original pre-fork develoment)
@@ -38,8 +38,8 @@
 #include "save_tests.h"
 #include "pluginscheduler.h"
 
-extern int g_max_hosts;
-extern int g_max_checks;
+extern int global_max_hosts;
+extern int global_max_checks;
 
 /**
  * @brief Library version check.
@@ -81,12 +81,15 @@ int
 common(l1, l2)
  struct arglist * l1, *l2;
 {
+ struct arglist* l2_start = l2;
+
  if(!l1 || !l2)
  {
   return 0;
  }
  while( l1->next != NULL )
  {
+  l2 = l2_start;
   while( l2->next != NULL )
   {
    if(strcmp(l1->name, l2->name) == 0)
@@ -154,17 +157,17 @@ get_max_hosts_number(globals, preferences)
 	{
 	  log_write("Error ! max_hosts = %d -- check %s\n", 
 		    max_hosts, (char *)arg_get_value(preferences, "config_file"));
-	  max_hosts = g_max_hosts;
+	  max_hosts = global_max_hosts;
 	}
-    else if(max_hosts > g_max_hosts)
+    else if(max_hosts > global_max_hosts)
      {
      	log_write("Client tried to raise the maximum hosts number - %d. Using %d. Change 'max_hosts' in openvasd.conf if \
 you believe this is incorrect\n",
-			max_hosts, g_max_hosts);
-	max_hosts = g_max_hosts;
+			max_hosts, global_max_hosts);
+	max_hosts = global_max_hosts;
      }
     }
-  else max_hosts = g_max_hosts;
+  else max_hosts = global_max_hosts;
   return(max_hosts);
 }
 
@@ -185,17 +188,17 @@ get_max_checks_number(globals, preferences)
 	{
 	  log_write("Error ! max_hosts = %d -- check %s\n", 
 		    max_checks, (char *)arg_get_value(preferences, "config_file"));
-	  max_checks = g_max_checks;
+	  max_checks = global_max_checks;
 	}
-    else if(max_checks > g_max_checks)
+    else if(max_checks > global_max_checks)
      {
      	log_write("Client tried to raise the maximum checks number - %d. Using %d. Change 'max_checks' in openvasd.conf if \
 you believe this is incorrect\n",
-			max_checks, g_max_checks);
-	max_checks = g_max_checks;
+			max_checks, global_max_checks);
+	max_checks = global_max_checks;
      }
     }
-  else max_checks = g_max_checks;
+  else max_checks = global_max_checks;
   return(max_checks);
 }
 
